# This Decorator Class is used to execute methods that can only be executed in a Django Framework
# They mainly inlude methods that use the django ORM to access a database
class IsDjangoAppClass(object):
    def __init__(self,flag):
        self.flag = flag
    def __call__(self, original_func):
        def wrappee( *args, **kwargs):
            # 'in decorator before wrapee with flag '
            if self.flag:
                original_func(*args,**kwargs)
            # 'in decorator after wrapee with flag '
        return wrappee


# Generated by Django 3.2.5 on 2022-07-14 10:32

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Callbacks',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('bank_id', models.IntegerField()),
                ('type_code', models.IntegerField()),
                ('reference', models.CharField(max_length=100)),
                ('callback', models.TextField()),
                ('request', models.JSONField(default=dict)),
                ('response', models.JSONField(default=dict)),
                ('request_time', models.DateTimeField(default=django.utils.timezone.now)),
                ('response_time', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]



# Generated by Django 3.2.5 on 2022-11-09 08:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0007_responselogs'),
    ]

    operations = [
        migrations.AddField(
            model_name='responselogs',
            name='ip',
            field=models.CharField(default=None, max_length=50, null=True),
        ),
    ]
